<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Archie Pro
 * @since Archie Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'archie_pro_about_section', array(
	'title'             => esc_html__( 'About Us','archie-pro' ),
	'description'       => esc_html__( 'About Section options.', 'archie-pro' ),
	'panel'             => 'archie_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'archie_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Archie_Pro_Switch_Control( $wp_customize, 'archie_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'archie-pro' ),
	'section'           => 'archie_pro_about_section',
	'on_off_label' 		=> archie_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'archie_pro_sanitize_select',
) );

$wp_customize->add_control( 'archie_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'archie-pro' ),
	'section'           => 'archie_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'archie_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'archie-pro' ),
		'post' 		=> esc_html__( 'Post', 'archie-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'archie-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'archie_pro_sanitize_page',
) );

$wp_customize->add_control( new Archie_Pro_Dropdown_Chooser( $wp_customize, 'archie_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'archie-pro' ),
	'section'           => 'archie_pro_about_section',
	'choices'			=> archie_pro_page_choices(),
	'active_callback'	=> 'archie_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'archie_pro_sanitize_page',
) );

$wp_customize->add_control( new Archie_Pro_Dropdown_Chooser( $wp_customize, 'archie_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'archie-pro' ),
	'section'           => 'archie_pro_about_section',
	'choices'			=> archie_pro_post_choices(),
	'active_callback'	=> 'archie_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'archie-pro' ),
	'section'        	=> 'archie_pro_about_section',
	'active_callback' 	=> 'archie_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[about_title]', array(
		'selector'            => '#about-us .entry-container .section-header h2.section-title',
		'settings'            => 'archie_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_about_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'archie-pro' ),
	'section'        	=> 'archie_pro_about_section',
	'active_callback' 	=> 'archie_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[about_description]', array(
		'selector'            => '#about-us .entry-container .entry-content',
		'settings'            => 'archie_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_about_description_partial',
    ) );
}

// about image setting and control.
$wp_customize->add_setting( 'archie_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'archie_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'archie_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'archie-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'archie-pro' ), 512, 520 ),
		'section'     		=> 'archie_pro_about_section',
		'active_callback'	=> 'archie_pro_is_about_section_content_custom_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'archie-pro' ),
	'section'        	=> 'archie_pro_about_section',
	'active_callback' 	=> 'archie_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about-us .read-more a',
		'settings'            => 'archie_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'archie_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'archie-pro' ),
	'section'        	=> 'archie_pro_about_section',
	'active_callback' 	=> 'archie_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );