<?php
/**
 * Latest Section options
 *
 * @package Theme Palace
 * @subpackage Archie Pro
 * @since Archie Pro 1.0.0
 */

// Add Latest section
$wp_customize->add_section( 'archie_pro_latest_section', array(
	'title'             => esc_html__( 'Latest','archie-pro' ),
	'description'       => esc_html__( 'Latest Section options.', 'archie-pro' ),
	'panel'             => 'archie_pro_front_page_panel',
) );

// Latest content enable control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[latest_section_enable]', array(
	'default'			=> 	$options['latest_section_enable'],
	'sanitize_callback' => 'archie_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Archie_Pro_Switch_Control( $wp_customize, 'archie_pro_theme_options[latest_section_enable]', array(
	'label'             => esc_html__( 'Latest Section Enable', 'archie-pro' ),
	'section'           => 'archie_pro_latest_section',
	'on_off_label' 		=> archie_pro_switch_options(),
) ) );

// latest note control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[latest_heading_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Archie_Pro_Note_Control( $wp_customize, 'archie_pro_theme_options[latest_heading_label]', array(
	'label'             => esc_html__( 'Heading Section', 'archie-pro' ),
	'section'           => 'archie_pro_latest_section',
	'active_callback'	=> 'archie_pro_is_latest_section_enable',
) ) );

// latest title setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[latest_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[latest_title]', array(
	'label'           	=> esc_html__( 'Title', 'archie-pro' ),
	'section'        	=> 'archie_pro_latest_section',
	'active_callback' 	=> 'archie_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[latest_title]', array(
		'selector'            => '#latest-projects .section-header h2.section-title',
		'settings'            => 'archie_pro_theme_options[latest_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_latest_title_partial',
    ) );
}

// latest subtitle setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[latest_subtitle]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['latest_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[latest_subtitle]', array(
	'label'           	=> esc_html__( 'Description', 'archie-pro' ),
	'section'        	=> 'archie_pro_latest_section',
	'active_callback' 	=> 'archie_pro_is_latest_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[latest_subtitle]', array(
		'selector'            => '#latest-projects .latest-content p',
		'settings'            => 'archie_pro_theme_options[latest_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_latest_subtitle_partial',
    ) );
}

// latest btn title setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[latest_btn_title]', array(
	'default'			=> $options['latest_btn_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[latest_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'archie-pro' ),
	'section'        	=> 'archie_pro_latest_section',
	'active_callback' 	=> 'archie_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[latest_btn_title]', array(
		'selector'            => '#latest-projects .read-more a.btn',
		'settings'            => 'archie_pro_theme_options[latest_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_latest_btn_title_partial',
    ) );
}

// latest btn title setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[latest_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> $options['latest_btn_url'],
) );

$wp_customize->add_control( 'archie_pro_theme_options[latest_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'archie-pro' ),
	'section'        	=> 'archie_pro_latest_section',
	'active_callback' 	=> 'archie_pro_is_latest_section_enable',
	'type'				=> 'url',
) );

// latest note control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[latest_content_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Archie_Pro_Note_Control( $wp_customize, 'archie_pro_theme_options[latest_content_label]', array(
	'label'             => esc_html__( 'Content Section', 'archie-pro' ),
	'section'           => 'archie_pro_latest_section',
	'active_callback'	=> 'archie_pro_is_latest_section_enable',
) ) );

// Latest content type control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[latest_content_type]', array(
	'default'          	=> $options['latest_content_type'],
	'sanitize_callback' => 'archie_pro_sanitize_select',
) );

$wp_customize->add_control( 'archie_pro_theme_options[latest_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'archie-pro' ),
	'section'           => 'archie_pro_latest_section',
	'type'				=> 'select',
	'active_callback' 	=> 'archie_pro_is_latest_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'archie-pro' ),
		'post' 		=> esc_html__( 'Post', 'archie-pro' ),
		'category' 	=> esc_html__( 'Category', 'archie-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[latest_count]', array(
	'default'          	=> $options['latest_count'],
	'sanitize_callback' => 'archie_pro_sanitize_number_range',
	'validate_callback' => 'archie_pro_validate_latest_count',
) );

$wp_customize->add_control( 'archie_pro_theme_options[latest_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'archie-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'archie-pro' ),
	'section'           => 'archie_pro_latest_section',
	'active_callback'   => 'archie_pro_is_latest_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['latest_count']; $i++ ) :
	// latest pages drop down chooser control and setting
	$wp_customize->add_setting( 'archie_pro_theme_options[latest_content_page_' . $i . ']', array(
		'sanitize_callback' => 'archie_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Archie_Pro_Dropdown_Chooser( $wp_customize, 'archie_pro_theme_options[latest_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'archie-pro' ), $i ),
		'section'           => 'archie_pro_latest_section',
		'choices'			=> archie_pro_page_choices(),
		'active_callback'	=> 'archie_pro_is_latest_section_content_page_enable',
	) ) );

	// latest posts drop down chooser control and setting
	$wp_customize->add_setting( 'archie_pro_theme_options[latest_content_post_' . $i . ']', array(
		'sanitize_callback' => 'archie_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Archie_Pro_Dropdown_Chooser( $wp_customize, 'archie_pro_theme_options[latest_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'archie-pro' ), $i ),
		'section'           => 'archie_pro_latest_section',
		'choices'			=> archie_pro_post_choices(),
		'active_callback'	=> 'archie_pro_is_latest_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'archie_pro_theme_options[latest_content_category]', array(
	'sanitize_callback' => 'archie_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Archie_Pro_Dropdown_Taxonomies_Control( $wp_customize,'archie_pro_theme_options[latest_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'archie-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'archie-pro' ),
	'section'           => 'archie_pro_latest_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'archie_pro_is_latest_section_content_category_enable'
) ) );
