<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Archie Pro
 * @since Archie Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'archie_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','archie-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'archie-pro' ),
	'panel'             => 'archie_pro_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'archie_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Archie_Pro_Switch_Control( $wp_customize, 'archie_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'archie-pro' ),
	'section'           => 'archie_pro_testimonial_section',
	'on_off_label' 		=> archie_pro_switch_options(),
) ) );

// testimonial note control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_heading_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Archie_Pro_Note_Control( $wp_customize, 'archie_pro_theme_options[testimonial_heading_label]', array(
	'label'             => esc_html__( 'Heading Section', 'archie-pro' ),
	'section'           => 'archie_pro_testimonial_section',
	'active_callback'	=> 'archie_pro_is_testimonial_section_enable',
) ) );

// testimonial title setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'archie-pro' ),
	'section'        	=> 'archie_pro_testimonial_section',
	'active_callback' 	=> 'archie_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[testimonial_title]', array(
		'selector'            => '#client-testimonial .section-header h2.section-title',
		'settings'            => 'archie_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_testimonial_title_partial',
    ) );
}

// testimonial subtitle setting and control
$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'archie_pro_theme_options[testimonial_subtitle]', array(
	'label'           	=> esc_html__( 'Description', 'archie-pro' ),
	'section'        	=> 'archie_pro_testimonial_section',
	'active_callback' 	=> 'archie_pro_is_testimonial_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'archie_pro_theme_options[testimonial_subtitle]', array(
		'selector'            => '#client-testimonial .testimonial-content p',
		'settings'            => 'archie_pro_theme_options[testimonial_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'archie_pro_testimonial_subtitle_partial',
    ) );
}

// testimonial note control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_content_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Archie_Pro_Note_Control( $wp_customize, 'archie_pro_theme_options[testimonial_content_label]', array(
	'label'             => esc_html__( 'Content Section', 'archie-pro' ),
	'section'           => 'archie_pro_testimonial_section',
	'active_callback'	=> 'archie_pro_is_testimonial_section_enable',
) ) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'archie_pro_sanitize_select',
) );

$wp_customize->add_control( 'archie_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'archie-pro' ),
	'section'           => 'archie_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'archie_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'archie-pro' ),
		'post' 		=> esc_html__( 'Post', 'archie-pro' ),
		'category' 	=> esc_html__( 'Category', 'archie-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'archie-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'archie_pro_sanitize_number_range',
	'validate_callback' => 'archie_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'archie_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'archie-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'archie-pro' ),
	'section'           => 'archie_pro_testimonial_section',
	'active_callback'   => 'archie_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'archie_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'archie_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Archie_Pro_Dropdown_Taxonomies_Control( $wp_customize,'archie_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'archie-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'archie-pro' ),
	'section'           => 'archie_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'archie_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'archie_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Archie_Pro_Dropdown_Chooser( $wp_customize, 'archie_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'archie-pro' ), $i ),
		'section'           => 'archie_pro_testimonial_section',
		'choices'			=> archie_pro_page_choices(),
		'active_callback'	=> 'archie_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'archie_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Archie_Pro_Dropdown_Chooser( $wp_customize, 'archie_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'archie-pro' ), $i ),
		'section'           => 'archie_pro_testimonial_section',
		'choices'			=> archie_pro_post_choices(),
		'active_callback'	=> 'archie_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'archie_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'archie-pro' ), $i ),
		'section'        	=> 'archie_pro_testimonial_section',
		'active_callback' 	=> 'archie_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'archie_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'archie-pro' ), $i ),
		'section'        	=> 'archie_pro_testimonial_section',
		'active_callback' 	=> 'archie_pro_is_testimonial_section_content_position_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'archie_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'archie-pro' ), $i ),
		'section'        	=> 'archie_pro_testimonial_section',
		'active_callback' 	=> 'archie_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'archie_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'archie_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'archie-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'archie-pro' ), 200, 200 ),
			'section'     		=> 'archie_pro_testimonial_section',
			'active_callback'	=> 'archie_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'archie_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'archie-pro' ), $i ),
		'section'        	=> 'archie_pro_testimonial_section',
		'active_callback' 	=> 'archie_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'archie_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Archie_Pro_Customize_Horizontal_Line( $wp_customize, 'archie_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'archie_pro_testimonial_section',
			'active_callback' => 'archie_pro_is_testimonial_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

